import * as React from 'react';
import PropTypes from 'prop-types';
import Tabs from '@mui/material/Tabs';
import Tab from '@mui/material/Tab';
import Typography from '@mui/material/Typography';
import Box from '@mui/material/Box';
import { FeedCard } from './FeedCard';
import { DiscoverClub } from './DiscoverClub';
import CreatePost from './CreatePost';

function CustomTabPanel(props) {
  const { children, value, index, ...other } = props;

  return (
    <div
      role="tabpanel"
      hidden={value !== index}
      id={`simple-tabpanel-${index}`}
      aria-labelledby={`simple-tab-${index}`}
      {...other}
    >
      {value === index && (
        <Box sx={{ p: 3 }}>
          <Typography>{children}</Typography>
        </Box>
      )}
    </div>
  );
}

CustomTabPanel.propTypes = {
  children: PropTypes.node,
  index: PropTypes.number.isRequired,
  value: PropTypes.number.isRequired,
};

function a11yProps(index) {
  return {
    id: `simple-tab-${index}`,
    'aria-controls': `simple-tabpanel-${index}`,
  };
}

export default function MainPostContent({ posts, community, firstCharacter, firstName }) {
  const [value, setValue] = React.useState(0);
  const [newPosts, setNewPosts] = React.useState(posts);

  const refreshPosts = (updatedPosts) => {
    setNewPosts([...updatedPosts]); // Update state with the new posts
  };

  const handleChange = (event, newValue) => {
    setValue(newValue);
  };

  return (
    <Box sx={{ width: '100%', marginTop: 5 }}>
      <Box sx={{ borderBottom: 1, borderColor: 'divider' }}>
        <Tabs
          value={value}
          onChange={handleChange}
          indicatorColor="secondary"
          textColor="secondary"
          variant="fullWidth"
          aria-label="full width tabs example"
        >
          <Tab label="Feed" {...a11yProps(0)} />
          <Tab label="Discover" {...a11yProps(1)} />
        </Tabs>
      </Box>
      <CustomTabPanel value={value} index={0}>
        <CreatePost
          firstCharacter={firstCharacter}
          firstName={firstName}
          onPostCreate={refreshPosts}
        />
        {/* Render the posts */}
        {newPosts && newPosts.map((post) => (
          <FeedCard key={post.id} single_post={post} />
        ))}
      </CustomTabPanel>
      <CustomTabPanel value={value} index={1}>
        <DiscoverClub community={community} />
      </CustomTabPanel>
    </Box>
  );
}
